==> wsit-impl-2.4.1-sources.jar: com/sun/xml/security/core/xenc/CVAdapter.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

/*
 * SCVAdapter.java
 *
 * Created on August 9, 2006, 2:47 PM
 */

package com.sun.xml.security.core.xenc;
import com.sun.xml.ws.security.opt.impl.enc.CryptoProcessor;

import javax.activation.CommandInfo;
import javax.activation.CommandMap;
import javax.activation.MailcapCommandMap;
import javax.xml.bind.annotation.adapters.XmlAdapter;
import javax.activation.DataHandler;

/**
 *
 * @author K.Venugopal@sun.com
 */
public class CVAdapter extends XmlAdapter<DataHandler,byte[]>{

    public static final String MIME_CIPHERVALUE = "application/ciphervalue";
    public static final String CV_HANDLER_CLASS = "com.sun.xml.ws.security.opt.impl.util.CVDataHandler";

    private CryptoProcessor cp;

    public CVAdapter() {
        ensureHandlerRegistered();
    }
    
    public CVAdapter(CryptoProcessor cp){
        this();
        this.cp = cp;
    }
    
    public DataHandler marshal(byte[] value){
        return new DataHandler(cp,"application/ciphervalue");
    }
    
    public byte[] unmarshal(DataHandler dh){
        throw new UnsupportedOperationException();
    }

    private void ensureHandlerRegistered() {
        CommandMap map = CommandMap.getDefaultCommandMap();
        CommandInfo[] commands = map.getAllCommands(MIME_CIPHERVALUE);
        if (commands != null && commands.length > 0) {
            for (CommandInfo command : commands) {
                if (CV_HANDLER_CLASS.equals(command.getCommandClass())) {
                    return;
                }
            }
        }
        if (map instanceof MailcapCommandMap) {
            ((MailcapCommandMap)map).addMailcap(MIME_CIPHERVALUE + ";;x-java-content-handler=" + CV_HANDLER_CLASS);
        }
    }

}

==> wsit-impl-3.0.2-sources.jar: com/sun/xml/security/core/xenc/CVAdapter.java <==
/*
 * Copyright (c) 2010, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*
 * SCVAdapter.java
 *
 * Created on August 9, 2006, 2:47 PM
 */

package com.sun.xml.security.core.xenc;
import com.sun.xml.ws.security.opt.impl.enc.CryptoProcessor;

import jakarta.activation.CommandInfo;
import jakarta.activation.CommandMap;
import jakarta.activation.MailcapCommandMap;
import jakarta.xml.bind.annotation.adapters.XmlAdapter;
import jakarta.activation.DataHandler;

/**
 *
 * @author K.Venugopal@sun.com
 */
public class CVAdapter extends XmlAdapter<DataHandler,byte[]>{

    public static final String MIME_CIPHERVALUE = "application/ciphervalue";
    public static final String CV_HANDLER_CLASS = "com.sun.xml.ws.security.opt.impl.util.CVDataHandler";

    private CryptoProcessor cp;

    public CVAdapter() {
        ensureHandlerRegistered();
    }
    
    public CVAdapter(CryptoProcessor cp){
        this();
        this.cp = cp;
    }
    
    public DataHandler marshal(byte[] value){
        return new DataHandler(cp,"application/ciphervalue");
    }
    
    public byte[] unmarshal(DataHandler dh){
        throw new UnsupportedOperationException();
    }

    private void ensureHandlerRegistered() {
        CommandMap map = CommandMap.getDefaultCommandMap();
        CommandInfo[] commands = map.getAllCommands(MIME_CIPHERVALUE);
        if (commands != null && commands.length > 0) {
            for (CommandInfo command : commands) {
                if (CV_HANDLER_CLASS.equals(command.getCommandClass())) {
                    return;
                }
            }
        }
        if (map instanceof MailcapCommandMap) {
            ((MailcapCommandMap)map).addMailcap(MIME_CIPHERVALUE + ";;x-java-content-handler=" + CV_HANDLER_CLASS);
        }
    }

}
